@@ -16,7 +16,7 @@
 #include <KActionCollection>
 #include <QDebug>
 #include <KLocalizedString>
-#include <kstandardgameaction.h>
+#include <KGameStandardAction>
 
 //classes
 #include "aicontroller.h"
@@ -33,7 +33,7 @@ KSquaresDemoWindow::KSquaresDemoWindow() : KXmlGuiWindow(), m_view(new GameBoard
     m_view->setDisabled(true);
     setCentralWidget(m_view);
 
-    KStandardGameAction::quit(qApp, &QApplication::quit, actionCollection());
+    KGameStandardAction::quit(qApp, &QApplication::quit, actionCollection());
     setupGUI();
 
     //QT5 statusBar()->insertPermanentItem(i18n("Current Player"), 0);
@@ -43,7 +43,7 @@ KSquaresDemoWindow::KSquaresDemoWindow() : KXmlGuiWindow(), m_view(new GameBoard
 void KSquaresDemoWindow::gameNew()
 {
     //create players
-    QVector<KSquaresPlayer> playerList;
+    QList<KSquaresPlayer> playerList;
     for (int i = 0; i < 4; i++) {
         QColor color;
         switch (i) {
@@ -86,6 +86,7 @@ void KSquaresDemoWindow::gameNew()
 
 void KSquaresDemoWindow::playerTakeTurn(KSquaresPlayer *currentPlayer)
 {
+    Q_UNUSED(currentPlayer);
     //QT5 statusBar()->changeItem(currentPlayer->name(), 0);
     QTimer::singleShot(200, this, &KSquaresDemoWindow::aiChooseLine);
 }
@@ -96,7 +97,7 @@ void KSquaresDemoWindow::aiChooseLine()
     sGame->addLineToIndex(ai.chooseLine());
 }
 
-void KSquaresDemoWindow::gameOver(const QVector<KSquaresPlayer> & /*playerList*/)
+void KSquaresDemoWindow::gameOver(const QList<KSquaresPlayer> & /*playerList*/)
 {
     //qDebug() << "Game Over";
     QTimer::singleShot(1000, this, &KSquaresDemoWindow::gameNew);
